# BSM Event Viewer for Solaris
# Copyright (C) 2000 Kevin Wenchel 
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

package time_dialog;

use Tk;
use POSIX;
use common;

############################
#
#
sub new(){

    my $class = shift;
    my $self = {};
    bless($self,$class);

    $date = shift;
              #   year    month  day     hr    sec
    $date =~ m/(\d\d\d\d)(\d\d)(\d\d)(\d\d)(\d\d)/;
    $self->{month}{prev} = $self->{month}{var}=$2;
    $self->{month}{size}= 2;
    $self->{month}{max} = 12;
    $self->{month}{min} = 1;
    $self->pad_fields("month");


    $self->{day}{prev}   = $self->{day}{var}=$3;
    $self->{day}{size}= 2;
    $self->{day}{max} = 31;
    $self->{day}{min} = 1;
    $self->pad_fields("day");

    $self->{year}{prev}  = $self->{year}{var}=$1;
    $self->{year}{size}= 4;
    $self->{year}{max} = 9999;
    $self->{year}{min} = 1980;
    $self->pad_fields("year");

    $self->{hour}{prev}  = $self->{hour}{var}=$4;
    $self->{hour}{size}= 2;
    $self->{hour}{max} = 23;
    $self->{hour}{min} = 0;
    $self->pad_fields("hour");

    $self->{minute}{prev}= $self->{minute}{var}=$5;
    $self->{minute}{size}= 2;
    $self->{minute}{max} = 59;
    $self->{minute}{min} = 0;
    $self->pad_fields("minute");

    $self->{day_entry}=undef;
    $self->{month_entry}=undef;
    $self->{year_entry}=undef;
    $self->{hour_entry}=undef;
    $self->{minute_entry}=undef;

    return $self;
}

#####################
#
#
sub enter_entry{
    $self = shift;
    $field = shift;
    $backup_value = $self->{$field};
}
#####################
#
#
sub pad_fields(){

    $self = shift;
    $field = shift;

   while(length($self->{$field}{var}) < $self->{$field}{size}){
	    $self->{$field}{var} = "0".$self->{$field}{var};
	}
}
#####################
#
#
sub leave_entry{

    $self = shift;
    $field = shift;

    if(($self->{$field}{var} =~ /[^0-9]+/) ||
       (length($self->{$field}{var}) > $self->{$field}{size})||
       ($self->{$field}{var} > $self->{$field}{max}) ||
       ($self->{$field}{var} < $self->{$field}{min}) ||
       ($self->{$field}{var} eq "")){

       common::error_dialog($mw,"Error","Numeric value between $self->{$field}{min} and $self->{$field}{max} expected for $field");
            
       $self->{$field}{var} = $self->{$field}{prev};
       return;
    }
    else{
       $self->pad_fields($field);
       $self->{$field}{prev} = $self->{$field}{var};
    }
    return;
  
	 #   $self->{day_entry}->focus();
	 #   $self->{day_entry}->selectionRange(0,'end');
}

#############################
#
#
sub time_dialog{
    my $self = shift;
    $mw = shift;
    my $x_coor = shift;
    my $y_coor = shift;
    my $label  = shift;

    $mw->Label(-text=>"Date:")->place(-x=>$x_coor,-y=>$y_coor);
    $mw->Label(-text=>"Time:")->place(-x=>$x_coor,-y=>$y_coor+30);

    $x_coor+=40;

    ##########
    # mon entry

    $self->{mon_entry} = $mw->Entry(-textvariable=>\$self->{month}{var},
			    -width=>2)->place(-x=>$x_coor,-y=>$y_coor);
   
    $self->{mon_entry}->bind("<FocusOut>",sub{ $self->leave_entry("month")});
    $mw->Label(-text=>"/")->place(-x=>$x_coor + 20,-y=>$y_coor);   
  
    ###########
    # day entry

    $self->{day_entry} = $mw->Entry(-textvariable=>\$self->{day}{var},
			    -width=>2)->place(-x=>$x_coor + 30,-y=>$y_coor);

    $self->{day_entry}->bind("<FocusOut>",sub{$self->leave_entry("day")});

    $mw->Label(-text=>"/")->place(-x=>$x_coor + 50,-y=>$y_coor);

    ##########
    # year entry

    $self->{year_entry} = $mw->Entry(-textvariable=>\$self->{year}{var},
			     -width=>4)->place(-x=>$x_coor + 60,-y=>$y_coor);

    $self->{year_entry}->bind("<FocusOut>",sub{$self->leave_entry("year")});

    $y_coor += 30;

    ##########
    # hour entry

    $self->{hour_entry} = $mw->Entry(-textvariable=>\$self->{hour}{var},
				     -width=>2)
	->place(-x=>$x_coor,-y=>$y_coor);
  
    $self->{hour_entry}->bind("<FocusOut>",sub{$self->leave_entry("hour")});
 
    $mw->Label(-text=>":")->place(-x=>$x_coor+20,-y=>$y_coor);
  
    ##########
    # minute entry
    
    $self->{minute_entry} = $mw->Entry(-textvariable=>\$self->{minute}{var},
				       width=>2)
	->place(-x=>$x_coor + 30,-y=>$y_coor);

    $self->{minute_entry}->bind("<FocusOut>",sub{$self->leave_entry("minute")});  
}

#########################
#
#
sub dump_values{
    $self = shift;
    # @fields = ("month",day,hour,minute);
    foreach $field ("month","day","hour","minute"){
      if($field ne "year"){
        while(length($self->{$field})<2){
            $self->{$field} = "0".$self->{$field};
	}
      }
    }

  $r = $self->{year}{var}.$self->{month}{var}.$self->{day}{var}.$self->{hour}{var}.$self->{minute}{var};
}
########################
#
#
sub update_time(){
   my  $self= shift;
   my $date = shift;
              #   year    month  day     hr    sec
    $date =~ m/(\d\d\d\d)(\d\d)(\d\d)(\d\d)(\d\d)/;
  
   $self->{month}{prev} = $self->{month}{var}=$2;
    $self->{month}{size}= 2;
    $self->{month}{max} = 12;
    $self->{month}{min} = 1;
    $self->pad_fields("month");

   $self->{day}{prev}   = $self->{day}{var} = $3;
    $self->{day}{size}= 2;
    $self->{day}{max} = 31;
    $self->{day}{min} = 1;
    $self->pad_fields("day");

    $self->{year}{prev}  = $self->{year}{var} = $1;
    $self->{year}{size}= 4;
    $self->{year}{max} = 9999;
    $self->{year}{min} = 1980;
    $self->pad_fields("year");

    $self->{hour}{prev}  = $self->{hour}{var}=$4;
   
    $self->{hour}{size}= 2;
    $self->{hour}{max} = 23;
    $self->{hour}{min} = 0;
    $self->pad_fields("hour");

    $self->{minute}{prev}= $self->{minute}{var}=$5;
 
    $self->{minute}{size}= 2;
    $self->{minute}{max} = 59;
    $self->{minute}{min} = 0;
    $self->pad_fields("minute");

}
########################
#
#
sub disable_entry(){
    my $self = shift;

    $self->{mon_entry}->configure(-state=>'disabled');
    $self->{day_entry}->configure(-state=>'disabled');
    $self->{year_entry}->configure(-state=>'disabled');
    $self->{hour_entry}->configure(-state=>'disabled');
    $self->{minute_entry}->configure(-state=>'disabled');
}
########################
#
#
sub enable_entry(){
    my $self = shift;

    $self->{mon_entry}->configure(-state=>'normal');
    $self->{day_entry}->configure(-state=>'normal');
    $self->{year_entry}->configure(-state=>'normal');
    $self->{hour_entry}->configure(-state=>'normal');
    $self->{minute_entry}->configure(-state=>'normal');
}
########################
#
#
#sub error_dialog(){
# #$title = shift;
# ($text) = @_;
# my $mw;
# $mw = MainWindow->new;
# 
# $mw->Label(-text=> $text)->grid();
# $mw->Button(-text => "OK",-command => sub{$mw->destroy()})->grid();
# MainLoop;
#}

1

























































































